==> zeno-python-sdk-0.0.2.tar.gz: zeno-python-sdk-0.0.2/zeno/constants/contracts.py <==

CONTRACT_ADDRESS = {
  # Metis
  1088: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xacEAa63A7AB1D385e472Ee625F3af33C41185934",
    "LIMIT_TRADE_HANDLER_ADDRESS": "",
    "CONFIG_STORAGE_ADDRESS": "0x6E8589868d6f9F7A17AE8bFF88978969aB7C2c51",
    "PERP_STORAGE_ADDRESS": "0x6e657247D92AdA604527FB31f7882A9060640e7D",
    "VAULT_STORAGE_ADDRESS": "0xFaEee486F4A53cdBEaBE37216bcf1016eB4E52D6",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x5577F217D22dBf5A77De5dc3621a28DAd5147Ac1",
    "TRADE_HELPER_ADDRESS": "0x620032734D1f6AAe257F00Dd5E114353c3F6c31B",
    "ONCHAIN_PRICELENS_ADDRESS": "0x7a18c976B3183d756d2E3dF3a747164B1c1A56a3",
    "CALC_PRICELENS_ADDRESS": "0x788C3E2311319e2061298D7b0090D06045827CC2",
    "ORDERBOOK_ORACLE_ADDRESS": "0x21f832ef69443300fcD24E8821BAB8aAca2D4404",
    "CALCULATOR_ADDRESS": "0x657a8E45050910204991974621eb258ed9c12009",
    "INTENT_HANDLER_ADDRESS": "0x1A610734b1b33BD0823C9aF75CacB3F91497fe64",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "0xbd6ec85003730A05fb9c864880f86f40F199B185",
  },
}

# ------ ABI Path ------
ERC20_ABI_PATH = "abis/ERC20.json"
CROSS_MARGIN_HANDLER_ABI_PATH = "abis/CrossMarginHandler.json"
LIMIT_TRADE_HANDLER_ABI_PATH = "abis/LimitTradeHandler.json"
VAULT_STORAGE_ABI_PATH = "abis/VaultStorage.json"
PERP_STORAGE_ABI_PATH = "abis/PerpStorage.json"
CONFIG_STORAGE_ABI_PATH = "abis/ConfigStorage.json"
CIX_PRICE_ADAPTER_ABI_PATH = "abis/CIXPriceAdapter.json"
TRADE_HELPER_ABI_PATH = "abis/TradeHelper.json"
ONCHAIN_PRICELENS_ABI_PATH = "abis/OnchainPricelens.json"
CALC_PRICELENS_ABI_PATH = "abis/CalcPricelens.json"
CALCULATOR_ABI_PATH = "abis/Calculator.json"
ORDERBOOK_ORACLE_ABI = "abis/OrderbookOracle.json"
ADAPTIVE_FEE_CALCULATOR_ABI = "abis/AdaptiveFeeCalculator.json"

==> zeno-python-sdk-0.0.3.tar.gz: zeno-python-sdk-0.0.3/zeno/constants/contracts.py <==

CONTRACT_ADDRESS = {
  # Metis
  1088: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xacEAa63A7AB1D385e472Ee625F3af33C41185934",
    "LIMIT_TRADE_HANDLER_ADDRESS": "",
    "CONFIG_STORAGE_ADDRESS": "0x6E8589868d6f9F7A17AE8bFF88978969aB7C2c51",
    "PERP_STORAGE_ADDRESS": "0x6e657247D92AdA604527FB31f7882A9060640e7D",
    "VAULT_STORAGE_ADDRESS": "0xFaEee486F4A53cdBEaBE37216bcf1016eB4E52D6",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x5577F217D22dBf5A77De5dc3621a28DAd5147Ac1",
    "TRADE_HELPER_ADDRESS": "0x620032734D1f6AAe257F00Dd5E114353c3F6c31B",
    "ONCHAIN_PRICELENS_ADDRESS": "0x7a18c976B3183d756d2E3dF3a747164B1c1A56a3",
    "CALC_PRICELENS_ADDRESS": "0x788C3E2311319e2061298D7b0090D06045827CC2",
    "ORDERBOOK_ORACLE_ADDRESS": "0x21f832ef69443300fcD24E8821BAB8aAca2D4404",
    "CALCULATOR_ADDRESS": "0x657a8E45050910204991974621eb258ed9c12009",
    "INTENT_HANDLER_ADDRESS": "0x1A610734b1b33BD0823C9aF75CacB3F91497fe64",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "0xbd6ec85003730A05fb9c864880f86f40F199B185",
  },
    59902: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xdB9C9575d70E18d44925748813c87E3c69f3ee80",
    "LIMIT_TRADE_HANDLER_ADDRESS": "",
    "CONFIG_STORAGE_ADDRESS": "0xb264217C6f8440f1cE38043A43c0713103987EBc",
    "PERP_STORAGE_ADDRESS": "0x25506c5c113C28f4D881D50e117fe365A0bCd662",
    "VAULT_STORAGE_ADDRESS": "0x9b1aE9EFaF4603D7F5C0705a1263120E9adaf74E",
    "DIX_PRICE_ADAPTER_ADDRESS": "0xDF10D7a1f22563F19FD93f55c597AAcdB7961B42",
    "TRADE_HELPER_ADDRESS": "0x3DB349b63b43cbc0Df688Ea36FE3b5Dfab9aD2f5",
    "ONCHAIN_PRICELENS_ADDRESS": "0x5963540d6750711Cd2BADe67b8065A6548cb9E8B",
    "CALC_PRICELENS_ADDRESS": "0x2175786e0c9BC1b4DDE99DA9e524a7aD17D4b6D8",
    "ORDERBOOK_ORACLE_ADDRESS": "0x391E0874DEd14512f965057B8a433E7daA549d3d",
    "CALCULATOR_ADDRESS": "0xF25110dE3072f265DAdA95D7117c65DfAe78Dc6D",
    "INTENT_HANDLER_ADDRESS": "0x9836b8a07ecDAb76737CAfd75A8DC36703BAe2e5",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "0x1E11f984863119494e2eadcc885D85D52F480E1C",
  },
}

# ------ ABI Path ------
ERC20_ABI_PATH = "abis/ERC20.json"
CROSS_MARGIN_HANDLER_ABI_PATH = "abis/CrossMarginHandler.json"
LIMIT_TRADE_HANDLER_ABI_PATH = "abis/LimitTradeHandler.json"
VAULT_STORAGE_ABI_PATH = "abis/VaultStorage.json"
PERP_STORAGE_ABI_PATH = "abis/PerpStorage.json"
CONFIG_STORAGE_ABI_PATH = "abis/ConfigStorage.json"
CIX_PRICE_ADAPTER_ABI_PATH = "abis/CIXPriceAdapter.json"
TRADE_HELPER_ABI_PATH = "abis/TradeHelper.json"
ONCHAIN_PRICELENS_ABI_PATH = "abis/OnchainPricelens.json"
CALC_PRICELENS_ABI_PATH = "abis/CalcPricelens.json"
CALCULATOR_ABI_PATH = "abis/Calculator.json"
ORDERBOOK_ORACLE_ABI = "abis/OrderbookOracle.json"
ADAPTIVE_FEE_CALCULATOR_ABI = "abis/AdaptiveFeeCalculator.json"
